use super::{PossessionData, WeaponData, WeaponAttackData, PossessionType};
use crate::models::item::SkillType;
use once_cell::sync::OnceCell;

pub fn data() -> &'static Vec<(PossessionType, PossessionData)> {
    static D: OnceCell<Vec<(PossessionType, PossessionData)>> =
        OnceCell::new();
    &D.get_or_init(|| vec!(
        (PossessionType::ButcherKnife,
         PossessionData {
             display: "butcher knife",
             details: "A 30 cm long stainless steel blade, sharp on one edge with a pointy tip. It looks perfect for butchering things, and in a pinch you could probably fight with it too.",
             aliases: vec!("butcher", "knife"),
             weight: 250,
             can_butcher: true,
             weapon_data: Some(WeaponData {
                 uses_skill: SkillType::Blades,
                 raw_min_to_learn: 0.0,
                 raw_max_to_learn: 2.0,
                 normal_attack: WeaponAttackData {
                     start_messages: vec!(
                         Box::new(|attacker, victim, exp|
                                  format!("{} raises {} butcher knife menancingly, preparing to attack {}",
                                          &attacker.display_for_sentence(exp, 1, true),
                                          &attacker.pronouns.possessive,
                                          &victim.display_for_sentence(exp, 1, false),
                                  )
                         )
                     ),
                     success_messages: vec!(
                         Box::new(|attacker, victim, part, exp|
                                  format!("{}'s butcher knife cuts into {}'s {}",
                                          &attacker.display_for_sentence(exp, 1, true),
                                          &victim.display_for_sentence(exp, 1, false),
                                          &part.display(victim.sex.clone())
                                  )
                         )
                     ),
                     mean_damage: 2.0,
                     stdev_damage: 2.0,
                     ..Default::default()
                 },
                 ..Default::default()
             }),
             ..Default::default()
         })
    ))
}
