use super::{
    Room, GridCoords, Exit, Direction, ExitTarget, MaterialType,
    SecondaryZoneRecord, ExitClimb
};
use ansi::ansi;
pub fn room_list() -> Vec<Room> {
    vec!(
        Room {
            zone: "chonkers",
            secondary_zones: vec!(
                SecondaryZoneRecord {
                    zone: "melbs",
                    short: ansi!("<bgyellow><blue>CG<reset>"),
                    grid_coords: GridCoords { x: 8, y: 2, z: 0 },
                    caption: Some("Chonker's Gym")
                }
            ),
            code: "chonkers_strength_hall",
            name: "Strength Hall",
            short: ansi!("<bgblack><white>SH<reset>"),
            description: ansi!("The first of several adjoined rooms making up Chonker's Gym, this space seems to be focused on strength training, and it exudes energy, filled with the invigorating scent of sweat and determination. The proprietor, Chonkers, stands at the center, a fitness enthusiast with a chiseled physique. Mirrors line the walls, reflecting the efforts of gym-goers as they push their limits. The atmosphere is charged with determination and camaraderie, accompanied by the rhythmic beat of energetic music. To the north, you notice a climbing wall towering over another room"),
            description_less_explicit: None,
            grid_coords: GridCoords { x: 0, y: 0, z: 0 },
            exits: vec!(
                Exit {
                    direction: Direction::SOUTH,
                    target: ExitTarget::Custom("room/melbs_bourkest_160"),
                    ..Default::default()
                },
                Exit {
                    direction: Direction::NORTH,
                    ..Default::default()
                },
            ),
            should_caption: true,
            ..Default::default()
        },
        Room {
            zone: "chonkers",
            code: "chonkers_endurance_hall",
            name: "Endurance Hall",
            short: ansi!("<bgblack><white>EH<reset>"),
            description: ansi!("A room that appears to be dedicated to endurance training. This space exudes a sense of purpose, with its focus on building stamina and resilience. At the northern edge of the room stands a towering climbing wall, inviting enthusiasts to conquer its challenging heights. The walls are adorned with motivational posters, inspiring climbers to push beyond their limits and embrace the thrill of conquering obstacles. Surrounding the climbing wall, a variety of endurance-focused machines beckon, ready to test and strengthen the resolve of those who dare to challenge themselves. The air hums with the sounds of exertion and determination, creating an atmosphere charged with the energy of individuals striving to improve their endurance and surpass their previous achievements"),
            description_less_explicit: None,
            grid_coords: GridCoords { x: 0, y: -1, z: 0 },
            exits: vec!(
                Exit {
                    direction: Direction::SOUTH,
                    ..Default::default()
                },
                Exit {
                    direction: Direction::UP,
                    exit_climb: Some(ExitClimb {
                        height: 5,
                        difficulty: 11
                    }),
                    ..Default::default()
                },
            ),
            material_type: MaterialType::Soft { damage_modifier: 0.5 },
            should_caption: true,
            ..Default::default()
        },
        Room {
            zone: "chonkers",
            code: "chonkers_climbing_top",
            name: "Top of the Climbing Wall",
            short: ansi!("<bgblack><white>CW<reset>"),
            description: ansi!("Congratulations, you made it to the top! It is quite snug up here in a little alove at the top of the wall, but the view from the top of the wall is amazing; you have a 180 degree view of buff men and women pumping iron and keeping themselves fit"),
            description_less_explicit: None,
            grid_coords: GridCoords { x: 0, y: -1, z: 1 },
            exits: vec!(
                Exit {
                    direction: Direction::DOWN,
                    exit_climb: Some(ExitClimb {
                        height: -5,
                        difficulty: 11
                    }),
                    ..Default::default()
                },
            ),
            material_type: MaterialType::Soft { damage_modifier: 0.5 },
            should_caption: true,
            ..Default::default()
        },
    )
}
